.. meta::
   :description: Gaitalytics API.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, api

Api
===


.. autofunction:: gaitalytics.api.load_config
.. autofunction:: gaitalytics.api.load_c3d_trial
.. autofunction:: gaitalytics.api.detect_events
.. autofunction:: gaitalytics.api.check_events
.. autofunction:: gaitalytics.api.write_events_to_c3d
.. autofunction:: gaitalytics.api.segment_trial
.. autofunction:: gaitalytics.api.time_normalise_trial
.. autofunction:: gaitalytics.api.calculate_features
.. autofunction:: gaitalytics.api.export_trial


